@@ -95,7 +95,7 @@ class DisplayShadowsocksr(object):
         else:
             logger.info("Current version: {0}".format(init_config.version))
             logger.info("Newest version: {0}".format(version))
-            logger.info("You can use 'pip(pip3) install shadowsocksr-cli' to update.")
+            logger.info("You can use 'pip(pip3) install shadowsocksr-cli -U' to update.")
         logger.info(tips_message)
 
 
@@ -212,7 +212,7 @@ class UpdateSystemProxy(object):
 
     @staticmethod
     @is_ubuntu
-    def open_global_proxy(local_port):
+    def open_global_proxy(local_port, http_port=80):
         cmd = "gsettings set org.gnome.system.proxy mode 'manual'"
         os.system(cmd)
         cmd = "gsettings set org.gnome.system.proxy.socks host {0}".format(Setting.get_value('local_address'))
@@ -225,12 +225,13 @@ class UpdateSystemProxy(object):
     @staticmethod
     @is_ubuntu
     def open_pac_proxy(local_port, http_port=80):
-        HandleHttpServer.handle_http_server("start", local_port, http_port)
-
         cmd = "gsettings set org.gnome.system.proxy autoconfig-url http://{0}:{1}/autoproxy.pac". \
             format(Setting.get_value('local_address'), http_port)
         os.system(cmd)
+        cmd = "gsettings set org.gnome.system.proxy mode 'auto'"
+        os.system(cmd)
         logger.info('Open pac proxy - {0}:{1}'.format(Setting.get_value('local_address'), local_port))
+        HandleHttpServer.handle_http_server("start", local_port, http_port)
 
     @staticmethod
     @is_ubuntu
